@@ -135,14 +135,9 @@ pub trait CustomElement {
     }
 }
 
-pub fn attach_shadow(el: impl ToJSValue, open: bool) {
+pub fn attach_shadow(el: impl ToJSValue, open: bool) -> HTMLElement {
     let shadow_dom = globals::get::<ShadowDom>();
-    shadow_dom.attach_shadow(el, open);
-}
-
-pub fn set_shadow_html(el: impl ToJSValue, html: &str) {
-    let shadow_dom = globals::get::<ShadowDom>();
-    shadow_dom.set_shadow_html(el, html);
+    shadow_dom.attach_shadow(el, open)
 }
 
 pub fn set_html(el: impl ToJSValue, html: &str) {
@@ -157,7 +152,6 @@ pub fn get_attribute(el: impl ToJSValue, name: &str) -> Option<String> {
 
 struct ShadowDom {
     fn_attach_shadow: JSInvoker,
-    fn_set_shadow_html: JSInvoker,
     fn_set_html: JSInvoker,
     fn_get_attribute: JSInvoker,
 }
@@ -165,10 +159,11 @@ struct ShadowDom {
 impl Default for ShadowDom {
     fn default() -> Self {
         ShadowDom {
-            fn_attach_shadow: js!((el,is_open)=>el.attachShadow({mode:is_open?"open":"closed"})),
-            fn_set_shadow_html: js!((el,html)=>el.shadowRoot.innerHTML = html),
+            fn_attach_shadow: js!((el,is_open)=> {
+                el.attachShadow({mode:is_open?"open":"closed"});
+                return el.shadowRoot;
+            }),
             fn_set_html: js!((el,html)=>{
-                debugger;
                 el.innerHTML = html
             }),
             fn_get_attribute: js!((el,name)=>el.getAttribute(name)),
@@ -177,12 +172,8 @@ impl Default for ShadowDom {
 }
 
 impl ShadowDom {
-    pub fn attach_shadow(&self, el: impl ToJSValue, is_open: bool) {
-        self.fn_attach_shadow.invoke_2(el, is_open);
-    }
-
-    pub fn set_shadow_html(&self, el: impl ToJSValue, html: &str) {
-        self.fn_set_shadow_html.invoke_2(el, html);
+    pub fn attach_shadow(&self, el: impl ToJSValue, is_open: bool) -> HTMLElement {
+        self.fn_attach_shadow.invoke_2(el, is_open).as_owned()
     }
 
     pub fn set_html(&self, el: impl ToJSValue, html: &str) {
